# gcalendar

A command-line tool to read your Google Calendar events in JSON format.


## Help

```shell script
usage: __main__.py [-h] [--no-of-days NO_OF_DAYS]
                   [--calendar [CALENDAR [CALENDAR ...]]] [--list-calendars]
                   [--client-id CLIENT_ID] [--client-secret CLIENT_SECRET]
                   [--account ACCOUNT]

Retrieve Google Calendar events.

optional arguments:
  -h, --help            show this help message and exit
  --no-of-days NO_OF_DAYS
                        number of days to include
  --calendar [CALENDAR [CALENDAR ...]]
  --list-calendars
  --client-id CLIENT_ID
                        the Google client id
  --client-secret CLIENT_SECRET
                        the Google client secret
  --account ACCOUNT     a name to uniquely identify the account
```

## License

GNU General Public License v3